@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996-2001 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2001 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996-2002 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 1999-2002 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #include "keymap.h"
 #include "mailbox.h"
 #include "url.h"
-#include "reldate.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -43,19 +42,19 @@ To contact the developers, please mail to <mutt-dev@mutt.org>.\n\
 To report a bug, please use the flea(1) utility.\n");
 
 static const char *Notice = N_("\
-Copyright (C) 1996-2001 Michael R. Elkins and others.\n\
+Copyright (C) 1996-2002 Michael R. Elkins and others.\n\
 Mutt comes with ABSOLUTELY NO WARRANTY; for details type `mutt -vv'.\n\
 Mutt is free software, and you are welcome to redistribute it\n\
 under certain conditions; type `mutt -vv' for details.\n");
 
 static const char *Copyright = N_("\
-Copyright (C) 1996-2001 Michael R. Elkins <me@cs.hmc.edu>\n\
-Copyright (C) 1996-2001 Brandon Long <blong@fiction.net>\n\
-Copyright (C) 1997-2001 Thomas Roessler <roessler@guug.de>\n\
-Copyright (C) 1998-2001 Werner Koch <wk@isil.d.shuttle.de>\n\
-Copyright (C) 1999-2001 Brendan Cully <brendan@kublai.com>\n\
-Copyright (C) 1999-2001 Tommi Komulainen <Tommi.Komulainen@iki.fi>\n\
-Copyright (C) 2000-2001 Edmund Grimley Evans <edmundo@rano.org>\n\
+Copyright (C) 1996-2002 Michael R. Elkins <me@mutt.org>\n\
+Copyright (C) 1996-2002 Brandon Long <blong@fiction.net>\n\
+Copyright (C) 1997-2002 Thomas Roessler <roessler@guug.de>\n\
+Copyright (C) 1998-2002 Werner Koch <wk@isil.d.shuttle.de>\n\
+Copyright (C) 1999-2002 Brendan Cully <brendan@kublai.com>\n\
+Copyright (C) 1999-2002 Tommi Komulainen <Tommi.Komulainen@iki.fi>\n\
+Copyright (C) 2000-2002 Edmund Grimley Evans <edmundo@rano.org>\n\
 \n\
 Lots of others not mentioned here contributed lots of code,\n\
 fixes, and suggestions.\n\
@@ -83,7 +82,8 @@ void mutt_exit (int code)
 
 static void mutt_usage (void)
 {
-  printf ("Mutt %s (%s)\n", MUTT_VERSION, ReleaseDate);
+  puts (mutt_make_version ());
+
   puts _(
 "usage: mutt [ -nRyzZ ] [ -e <cmd> ] [ -F <file> ] [ -m <type> ] [ -f <file> ]\n\
        mutt [ -nx ] [ -e <cmd> ] [ -a <file> ] [ -F <file> ] [ -H <file> ] [ -i <file> ] [ -s <subj> ] [ -b <addr> ] [ -c <addr> ] <addr> [ ... ]\n\
@@ -118,7 +118,7 @@ static void show_version (void)
 {
   struct utsname uts;
 
-  printf ("Mutt %s (%s)\n", MUTT_VERSION, ReleaseDate);
+  puts (mutt_make_version());
   puts (_(Notice));
 
   uname (&uts);
@@ -392,9 +392,11 @@ static void show_version (void)
 #else
   puts ("-MIXMASTER");
 #endif
-  
+
   puts(_(ReachingUs));
 
+  mutt_print_patchlist();
+  
   exit (0);
 }
 
@@ -583,7 +585,7 @@ int main (int argc, char **argv)
       show_version ();
       break;
     default:
-      printf ("Mutt %s (%s)\n", MUTT_VERSION, ReleaseDate);
+      puts (mutt_make_version ());
       puts (_(Copyright));
       puts (_(ReachingUs));
       exit (0);
